@@ -50,7 +50,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ApplySnapshot(self, request):
@@ -77,7 +77,33 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ApplySnapshotGroup(self, request):
+        """本接口（ApplySnapshotGroup）用于回滚快照组，将实例恢复到创建快照组时刻的状态。
+        * 1.可选择快照组全部或部分盘进行回滚；
+        * 2.如果回滚的盘中包含已挂载的盘，要求这些盘必须挂载在同一实例上，且要求该实例已关机才能回滚；
+        * 3.回滚为异步操作，接口返回成功不代表回滚成功，可通过调DescribeSnapshotGroups接口查询快照组的状态。
+
+        :param request: Request instance for ApplySnapshotGroup.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.ApplySnapshotGroupRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.ApplySnapshotGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ApplySnapshotGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.ApplySnapshotGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def AttachDisks(self, request):
@@ -103,7 +129,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def BindAutoSnapshotPolicy(self, request):
@@ -129,7 +155,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CopySnapshotCrossRegions(self, request):
@@ -155,7 +181,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateAutoSnapshotPolicy(self, request):
@@ -181,7 +207,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateDiskBackup(self, request):
@@ -204,7 +230,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateDisks(self, request):
@@ -231,7 +257,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateSnapshot(self, request):
@@ -258,7 +284,32 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateSnapshotGroup(self, request):
+        """本接口（CreateSnapshotGroup）用于创建快照组。
+        * 创建快照组的云硬盘列表必须挂载在同一实例上；
+        * 可选择挂载在实例上的全部或部分盘创建快照组。
+
+        :param request: Request instance for CreateSnapshotGroup.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.CreateSnapshotGroupRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.CreateSnapshotGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateSnapshotGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateSnapshotGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteAutoSnapshotPolicies(self, request):
@@ -283,7 +334,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteDiskBackups(self, request):
@@ -306,7 +357,32 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteSnapshotGroup(self, request):
+        """本接口（DeleteSnapshotGroup）用于删除快照组，一次调用仅支持删除一个快照组。
+        * 默认会删除快照组内的所有快照；
+        * 如果快照组内的快照有关联镜像，则删除失败，所有快照均不会删除；如果需要同时删除快照绑定的镜像，可传入参数DeleteBindImages等于true。
+
+        :param request: Request instance for DeleteSnapshotGroup.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.DeleteSnapshotGroupRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.DeleteSnapshotGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteSnapshotGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteSnapshotGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteSnapshots(self, request):
@@ -332,7 +408,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAutoSnapshotPolicies(self, request):
@@ -358,7 +434,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDiskAssociatedAutoSnapshotPolicy(self, request):
@@ -381,7 +457,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDiskBackups(self, request):
@@ -407,7 +483,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDiskConfigQuota(self, request):
@@ -430,32 +506,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeDiskOperationLogs(self, request):
-        """接口已废弃，切换至云审计接口。见https://tapd.woa.com/pro/prong/stories/view/1010114221880719007
-
-        查询云盘操作日志功能已迁移至LookUpEvents接口（https://cloud.tencent.com/document/product/629/12359），本接口（DescribeDiskOperationLogs）即将下线，后续不再提供调用，请知悉。
-
-        :param request: Request instance for DescribeDiskOperationLogs.
-        :type request: :class:`tencentcloud.cbs.v20170312.models.DescribeDiskOperationLogsRequest`
-        :rtype: :class:`tencentcloud.cbs.v20170312.models.DescribeDiskOperationLogsResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeDiskOperationLogs", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeDiskOperationLogsResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDiskStoragePool(self, request):
@@ -481,7 +532,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDisks(self, request):
@@ -507,7 +558,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeInstancesDiskNum(self, request):
@@ -532,32 +583,55 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DescribeSnapshotOperationLogs(self, request):
-        """接口已废弃，切换至云审计接口。见https://tapd.woa.com/pro/prong/stories/view/1010114221880719007
+    def DescribeSnapshotGroups(self, request):
+        """本接口（DescribeSnapshotGroups）用于查询快照组列表。
+        * 可以根据快照组ID、快照组状态、快照组关联的快照ID等来查询快照组列表，不同条件之间为与(AND)的关系，过滤信息详细请见过滤器`Filter`。
+        * 如果参数为空，返回当前用户一定数量（`Limit`所指定的数量，默认为20）的快照组列表。
 
-        查询快照操作日志功能已迁移至LookUpEvents接口（https://cloud.tencent.com/document/product/629/12359），本接口（DescribeSnapshotOperationLogs）即将下线，后续不再提供调用，请知悉。
-
-        :param request: Request instance for DescribeSnapshotOperationLogs.
-        :type request: :class:`tencentcloud.cbs.v20170312.models.DescribeSnapshotOperationLogsRequest`
-        :rtype: :class:`tencentcloud.cbs.v20170312.models.DescribeSnapshotOperationLogsResponse`
+        :param request: Request instance for DescribeSnapshotGroups.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.DescribeSnapshotGroupsRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.DescribeSnapshotGroupsResponse`
 
         """
         try:
             params = request._serialize()
             headers = request.headers
-            body = self.call("DescribeSnapshotOperationLogs", params, headers=headers)
+            body = self.call("DescribeSnapshotGroups", params, headers=headers)
             response = json.loads(body)
-            model = models.DescribeSnapshotOperationLogsResponse()
+            model = models.DescribeSnapshotGroupsResponse()
             model._deserialize(response["Response"])
             return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeSnapshotOverview(self, request):
+        """该接口用于查询用户快照使用概览，包括快照总容量、计费容量等信息。
+
+        :param request: Request instance for DescribeSnapshotOverview.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.DescribeSnapshotOverviewRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.DescribeSnapshotOverviewResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSnapshotOverview", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSnapshotOverviewResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSnapshotSharePermission(self, request):
@@ -580,7 +654,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSnapshots(self, request):
@@ -606,7 +680,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DetachDisks(self, request):
@@ -632,11 +706,13 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetSnapOverview(self, request):
-        """获取快照概览信息
+        """为进一步规范化API命名，该接口决定预下线，新接口命名为：DescribeSnapshotOverview
+
+        获取快照概览信息
 
         :param request: Request instance for GetSnapOverview.
         :type request: :class:`tencentcloud.cbs.v20170312.models.GetSnapOverviewRequest`
@@ -655,7 +731,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def InitializeDisks(self, request):
@@ -682,7 +758,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def InquirePriceModifyDiskBackupQuota(self, request):
@@ -705,7 +781,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def InquirePriceModifyDiskExtraPerformance(self, request):
@@ -728,7 +804,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def InquiryPriceCreateDisks(self, request):
@@ -753,7 +829,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def InquiryPriceRenewDisks(self, request):
@@ -780,7 +856,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def InquiryPriceResizeDisk(self, request):
@@ -803,7 +879,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyAutoSnapshotPolicyAttribute(self, request):
@@ -829,7 +905,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyDiskAttributes(self, request):
@@ -854,7 +930,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyDiskBackupQuota(self, request):
@@ -877,7 +953,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyDiskExtraPerformance(self, request):
@@ -902,15 +978,13 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyDisksChargeType(self, request):
-        """接口请求域名： cbs.tencentcloudapi.com 。
+        """本接口 (ModifyDisksChargeType) 用于切换云硬盘的计费模式。
 
-        本接口 (ModifyDisksChargeType) 用于切换云盘的计费模式。
-
-        非弹性云盘不支持此接口，请通过修改实例计费模式接口将实例连同非弹性云盘一起转换。
+        非弹性云硬盘不支持此接口，请通过修改实例计费模式接口将实例连同非弹性云硬盘一起转换。
         默认接口请求频率限制：10次/秒。
 
         :param request: Request instance for ModifyDisksChargeType.
@@ -930,7 +1004,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyDisksRenewFlag(self, request):
@@ -953,14 +1027,14 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifySnapshotAttribute(self, request):
         """本接口（ModifySnapshotAttribute）用于修改指定快照的属性。
 
-        * 当前仅支持修改快照名称及将非永久快照修改为永久快照。
-        * “快照名称”仅为方便用户自己管理之用，腾讯云并不以此名称作为提交工单或是进行快照管理操作的依据。
+        * 本接口支持修改快照名称及到期时间，以及将非永久快照修改为永久快照。
+        * “快照名称”仅为方便用户管理之用，腾讯云并不以此名称作为提交工单或是进行快照管理操作的依据。
 
         :param request: Request instance for ModifySnapshotAttribute.
         :type request: :class:`tencentcloud.cbs.v20170312.models.ModifySnapshotAttributeRequest`
@@ -979,7 +1053,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifySnapshotsSharePermission(self, request):
@@ -1008,7 +1082,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def RenewDisk(self, request):
@@ -1034,7 +1108,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ResizeDisk(self, request):
@@ -1060,7 +1134,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def TerminateDisks(self, request):
@@ -1087,7 +1161,7 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UnbindAutoSnapshotPolicy(self, request):
@@ -1113,4 +1187,4 @@ class CbsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
